@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2013 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2014 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -141,6 +141,11 @@ typedef struct nv_ioctl_rm_api_old_version
 #define NV_RM_API_OLD_VERSION_MAGIC_OVERRIDE_REQ    (NV_RM_API_OLD_VERSION_MAGIC_REQ ^ '2')
 #define NV_RM_API_OLD_VERSION_MAGIC_IGNORE           0xffffffff
 
+typedef enum {
+    NV_CPU_TYPE_UNKNOWN = 0,
+    NV_CPU_TYPE_ARM_A15
+} nv_cpu_type_t;
+
 /* alloc event */
 typedef struct nv_ioctl_alloc_os_event
 {
@@ -227,7 +232,8 @@ typedef union
 
 typedef struct
 {
-    NvU64 address;
+    NvU64 cpu_address;
+    NvU64 bus_address;
     NvU64 strapped_size;
     NvU64 size;
     NvU32 offset;
@@ -242,10 +248,20 @@ typedef struct
     NvU32 *data;
 } nv_parm_t;
 
+#define NV_RM_PAGE_SHIFT    12
+#define NV_RM_PAGE_SIZE     (1 << NV_RM_PAGE_SHIFT)
+#define NV_RM_PAGE_MASK     (NV_RM_PAGE_SIZE - 1)
+
+#define NV_RM_TO_OS_PAGE_SHIFT      (OS_PAGE_SHIFT - NV_RM_PAGE_SHIFT)
+#define NV_RM_PAGES_PER_OS_PAGE     (1U << NV_RM_TO_OS_PAGE_SHIFT)
+#define NV_RM_PAGES_TO_OS_PAGES(count) \
+    ((((NvUPtr)(count)) >> NV_RM_TO_OS_PAGE_SHIFT) + \
+     ((((count) & ((1 << NV_RM_TO_OS_PAGE_SHIFT) - 1)) != 0) ? 1 : 0))
+
 #if defined(NVCPU_X86_64)
-#define NV_STACK_SIZE (RM_PAGE_SIZE * 3)
+#define NV_STACK_SIZE (NV_RM_PAGE_SIZE * 3)
 #else
-#define NV_STACK_SIZE (RM_PAGE_SIZE * 2)
+#define NV_STACK_SIZE (NV_RM_PAGE_SIZE * 2)
 #endif
 
 typedef struct nv_stack_s
@@ -426,17 +442,18 @@ typedef struct
     (nv_state_t *)((pGpu) ? (pGpu)->pOsHwInfo : NULL)
 
 #define IS_REG_OFFSET(nv, offset, length)                                       \
-    (((offset) >= (nv)->regs->address) &&                                       \
-    (((offset) + ((length)-1)) <= (nv)->regs->address + ((nv)->regs->size-1)))
+    (((offset) >= (nv)->regs->cpu_address) &&                                   \
+    (((offset) + ((length)-1)) <=                                               \
+        (nv)->regs->cpu_address + ((nv)->regs->size-1)))
 
 #define IS_FB_OFFSET(nv, offset, length)                                        \
-    (((offset) >= (nv)->fb->address) &&                                         \
-    (((offset) + ((length)-1)) <= (nv)->fb->address + ((nv)->fb->size-1)))
+    (((offset) >= (nv)->fb->cpu_address) &&                                     \
+    (((offset) + ((length)-1)) <= (nv)->fb->cpu_address + ((nv)->fb->size-1)))
 
 #define IS_UD_OFFSET(nv, offset, length)                                        \
-    (((nv)->ud.address != 0) && ((nv)->ud.size != 0) &&                         \
-    ((offset) >= (nv)->ud.address) &&                                           \
-    (((offset) + ((length)-1)) <= (nv)->ud.address + ((nv)->ud.size-1)))
+    (((nv)->ud.cpu_address != 0) && ((nv)->ud.size != 0) &&                     \
+    ((offset) >= (nv)->ud.cpu_address) &&                                       \
+    (((offset) + ((length)-1)) <= (nv)->ud.cpu_address + ((nv)->ud.size-1)))
 
 /* device name length; must be atleast 8 */
 
@@ -563,6 +580,7 @@ RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list   (nv_state_t *, void *, NvU64, N
 RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *, void *, NvU32);
 #endif
 RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
+NvU64      NV_API_CALL  nv_get_dma_start_address (nv_state_t *);
 
 /*
  * ---------------------------------------------------------------------------
@@ -632,6 +650,7 @@ RM_STATUS  NV_API_CALL  rm_p2p_init_mapping       (nv_stack_t *, NvU64, NvU64 *,
 RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
 RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
 RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
+RM_STATUS  NV_API_CALL  rm_get_cpu_type           (nv_stack_t *, nv_cpu_type_t *);
 
 RM_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nv_stack_t *, nvgpuSessionHandle_t *);
 RM_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nv_stack_t *, nvgpuSessionHandle_t);
