@@ -44,7 +44,7 @@ int nvidia_attach(device_t dev)
 
     for (i = 0; i < NV_GPU_NUM_BARS; i++) {
         if (sc->BAR_recs[i] != NULL) {
-            nv->bars[i].address = rman_get_start(sc->BAR_recs[i]);
+            nv->bars[i].cpu_address = rman_get_start(sc->BAR_recs[i]);
             nv->bars[i].strapped_size = rman_get_size(sc->BAR_recs[i]);
             nv->bars[i].size = nv->bars[i].strapped_size;
         }
@@ -81,7 +81,7 @@ int nvidia_attach(device_t dev)
                 goto failed;
 
             sglist_append_phys(sc->BAR_sg_lists[i],
-                    nv->bars[i].address, nv->bars[i].size);
+                    nv->bars[i].cpu_address, nv->bars[i].size);
 
             sc->BAR_objects[i] = NV_VM_PAGER_ALLOCATE(OBJT_SG,
                     sc->BAR_sg_lists[i],
@@ -376,9 +376,9 @@ int nvidia_get_card_info(void *args, int size)
         ci[i].pci_info.device_id = nv->pci_info.device_id;
         ci[i].gpu_id             = nv->gpu_id;
         ci[i].interrupt_line     = nv->interrupt_line;
-        ci[i].fb_address         = nv->fb->address;
+        ci[i].fb_address         = nv->fb->cpu_address;
         ci[i].fb_size            = nv->fb->size;
-        ci[i].reg_address        = nv->regs->address;
+        ci[i].reg_address        = nv->regs->cpu_address;
         ci[i].reg_size           = nv->regs->size;
         ci[i].minor_number       = i;
     }
@@ -537,7 +537,7 @@ int nvidia_open_dev(
             if (!sc->UD_sg_list)
                 goto failed;
 
-            sglist_append_phys(sc->UD_sg_list, nv->ud.address, nv->ud.size);
+            sglist_append_phys(sc->UD_sg_list, nv->ud.cpu_address, nv->ud.size);
 
             sc->UD_object = NV_VM_PAGER_ALLOCATE(OBJT_SG, sc->UD_sg_list,
                     nv->ud.size, (VM_PROT_READ | VM_PROT_WRITE),
@@ -1196,12 +1196,12 @@ RM_STATUS NV_API_CALL nv_alloc_pages(
     if (!alloc_type_contiguous) {
         if (nv_alloc_system_pages(nv, count, cache_type, zero,
                     pte_array, private)) {
-            status = RM_ERR_NO_FREE_MEM;
+            status = RM_ERR_NO_MEMORY;
         }
     } else {
         if (nv_alloc_contig_pages(nv, count, cache_type, zero,
                     pte_array, private)) {
-            status = RM_ERR_NO_FREE_MEM;
+            status = RM_ERR_NO_MEMORY;
         }
     }
 
@@ -1322,17 +1322,17 @@ int nvidia_mmap_dev_single(
     if (IS_UD_OFFSET(nv, *offset, size)) {
         *object = sc->UD_object;
         vm_object_reference(*object);
-        *offset = (*offset - nv->ud.address);
+        *offset = (*offset - nv->ud.cpu_address);
         return 0;
     } else if (IS_FB_OFFSET(nv, *offset, size)) {
         *object = sc->BAR_objects[NV_GPU_BAR_INDEX_FB];
         vm_object_reference(*object);
-        *offset = (*offset - nv->fb->address);
+        *offset = (*offset - nv->fb->cpu_address);
         return 0;
     } else if (IS_REG_OFFSET(nv, *offset, size)) {
         *object = sc->BAR_objects[NV_GPU_BAR_INDEX_REGS];
         vm_object_reference(*object);
-        *offset = (*offset - nv->regs->address);
+        *offset = (*offset - nv->regs->cpu_address);
         return 0;
     }
 
@@ -1482,3 +1482,10 @@ RM_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
 {
     return RM_ERR_NOT_SUPPORTED;
 }
+
+NvU64 NV_API_CALL nv_get_dma_start_address(
+    nv_state_t *nv
+)
+{
+    return 0;
+}
