@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2013 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2014 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -71,7 +71,8 @@ typedef struct
 
 NvU32       NV_API_CALL  os_get_page_size            (void);
 NvU64       NV_API_CALL  os_get_page_mask            (void);
-NvU64       NV_API_CALL  os_get_system_memory_size   (void);
+NvU8        NV_API_CALL  os_get_page_shift           (void);
+NvU64       NV_API_CALL  os_get_num_phys_pages       (void);
 RM_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU32);
 void        NV_API_CALL  os_free_mem                 (void *);
 RM_STATUS   NV_API_CALL  os_get_current_time         (NvU32 *, NvU32 *);
@@ -96,7 +97,7 @@ RM_STATUS   NV_API_CALL  os_pci_read_dword           (void *, NvU32, NvU32 *);
 RM_STATUS   NV_API_CALL  os_pci_write_byte           (void *, NvU32, NvU8);
 RM_STATUS   NV_API_CALL  os_pci_write_word           (void *, NvU32, NvU16);
 RM_STATUS   NV_API_CALL  os_pci_write_dword          (void *, NvU32, NvU32);
-void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32);
+void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32, NvU32);
 void        NV_API_CALL  os_unmap_kernel_space       (void *, NvU64);
 void*       NV_API_CALL  os_map_user_space           (NvU64, NvU64, NvU32, NvU32, void **);
 void        NV_API_CALL  os_unmap_user_space         (void *, NvU64, void *);
@@ -193,6 +194,8 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 // #define NV_MEMORY_TYPE_AGP          1
 #define NV_MEMORY_TYPE_REGISTERS    2
 #define NV_MEMORY_TYPE_FRAMEBUFFER  3
+#define NV_MEMORY_TYPE_INSTANCE     4
+#define NV_MEMORY_TYPE_DEVICE_MMIO  5  /*  All kinds of MMIO referred by NVRM e.g. BARs and MCFG of device */
 
 #define NV_MEMORY_NONCONTIGUOUS     0
 #define NV_MEMORY_CONTIGUOUS        1
@@ -205,6 +208,7 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define NV_MEMORY_WRITEBACK         5
 #define NV_MEMORY_DEFAULT           6
 #define NV_MEMORY_UNCACHED_WEAK     7
+#define NV_MEMORY_UNCACHED_DEVICE   8
 
 #define NV_PROTECT_READABLE   1
 #define NV_PROTECT_WRITEABLE  2
@@ -219,13 +223,9 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
  * pages. make sure we can mask and twiddle with these addresses when
  * PAGE_SIZE isn't what we want.
  */
-#define RM_PAGE_SIZE                4096
 #define OS_PAGE_SIZE                (os_get_page_size())
 #define OS_PAGE_MASK                (os_get_page_mask())
-
-#define RM_PAGES_PER_OS_PAGES       (OS_PAGE_SIZE/RM_PAGE_SIZE)
-#define RM_PAGES_TO_OS_PAGES(count) (((count) + RM_PAGES_PER_OS_PAGES - 1) \
-                                       / RM_PAGES_PER_OS_PAGES)
+#define OS_PAGE_SHIFT               (os_get_page_shift())
 
 #define IS_VGX_HYPER()              os_is_vgx_hyper()
 
